"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const os_1 = __importDefault(require("os"));
const fs_1 = __importDefault(require("fs"));
class Config {
    constructor() {
        this.defaultBaseConfig = {
            currentPath: process.cwd(),
            port: 3000
        };
        this.defaultSavedSchemes = [];
        this.baseDirectoryPath = path_1.default.resolve(os_1.default.homedir(), ".steamwd/");
        this.baseConfigPath = path_1.default.resolve(this.baseDirectoryPath, "main.json");
        this.savedSchemesPath = path_1.default.resolve(this.baseDirectoryPath, "savedSchemes.json");
        this.prepareFolders();
        this.baseConfig = this.readMainConfig();
        this.savedSchemesConfig = this.readSavedSchemesConfig();
    }
    prepareFolders() {
        if (!fs_1.default.existsSync(this.baseConfigPath))
            fs_1.default.mkdirSync(this.baseDirectoryPath);
        if (!fs_1.default.existsSync(this.baseConfigPath))
            this.writeFile(this.baseConfigPath, this.defaultBaseConfig);
        if (!fs_1.default.existsSync(this.savedSchemesPath))
            this.writeFile(this.savedSchemesPath, this.defaultSavedSchemes);
    }
    readMainConfig() {
        try {
            return Object.assign(Object.assign({}, this.defaultBaseConfig), JSON.parse(fs_1.default.readFileSync(this.baseConfigPath, "utf-8")));
        }
        catch (error) {
            return this.defaultBaseConfig;
        }
    }
    readSavedSchemesConfig() {
        try {
            return JSON.parse(fs_1.default.readFileSync(this.savedSchemesPath, "utf-8"));
        }
        catch (error) {
            return this.defaultSavedSchemes;
        }
    }
    writeFile(filePath, config) {
        fs_1.default.writeFileSync(filePath, JSON.stringify(config));
    }
    updateMainConfig(config) {
        this.writeFile(this.baseConfigPath, config);
        this.baseConfig = this.readMainConfig();
    }
    updateSavedSchemes(schemes) {
        this.writeFile(this.savedSchemesPath, schemes);
        this.savedSchemesConfig = this.readSavedSchemesConfig();
    }
}
exports.default = new Config();
