"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.wdClient = exports.startWeb = void 0;
const express_1 = __importDefault(require("express"));
const morgan_1 = __importDefault(require("morgan"));
const path_1 = __importDefault(require("path"));
const body_parser_1 = __importDefault(require("body-parser"));
const router_1 = __importDefault(require("./router"));
const chalk_1 = __importDefault(require("chalk"));
const http_1 = __importDefault(require("http"));
const cors_1 = __importDefault(require("cors"));
const config_1 = __importDefault(require("./config"));
const api_1 = require("../api");
const webSocket_1 = require("./webSocket");
const wdClient = new api_1.Client();
exports.wdClient = wdClient;
const app = (0, express_1.default)();
const server = http_1.default.createServer(app);
function startAPI() {
    app.use((0, cors_1.default)());
    app.use(express_1.default.static(path_1.default.join(__dirname, '/public')));
    app.use((0, morgan_1.default)('dev'));
    app.use(body_parser_1.default.json());
    app.use(body_parser_1.default.urlencoded({ extended: true }));
    app.use('/api', router_1.default);
    app.get('/', (req, res, next) => {
        if (process.env.NODE_ENV === "dev")
            res.redirect("http://localhost:3000/");
        else
            res.sendFile(path_1.default.join(__dirname, '/public/index.html'));
    });
}
function startWeb() {
    config_1.default.baseConfig.currentPath = process.cwd();
    config_1.default.updateMainConfig(config_1.default.baseConfig);
    var socket = new webSocket_1.WebSocket(server);
    startAPI();
    const port = config_1.default.baseConfig.port || process.env.PORT || 8080;
    server.listen(port);
    console.log(chalk_1.default.green("Server is ready on ") + chalk_1.default.red(port));
}
exports.startWeb = startWeb;
