"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_extra_1 = __importDefault(require("fs-extra"));
const glob_1 = __importDefault(require("glob"));
const path_1 = __importDefault(require("path"));
let isFile = (fullPath) => {
    var name = path_1.default.basename(fullPath);
    if (name.includes('.'))
        return true;
    else
        return false;
};
var schemes = [
    {
        id: 0,
        name: "Delete",
        description: "Delete file or folder",
        params: [
            {
                name: "Path"
            }
        ],
        acceptChilds: false,
        execute: (params) => {
            if (params[0] && fs_extra_1.default.existsSync(params[0]))
                if (isFile(params[0]))
                    fs_extra_1.default.unlinkSync(params[0]);
                else
                    fs_extra_1.default.rmSync(params[0], { recursive: true });
        }
    },
    {
        id: 1,
        name: "Create",
        description: "Create file or folder",
        params: [
            {
                name: "Name"
            }
        ],
        acceptChilds: false,
        execute: (params) => {
            if (isFile(params[0])) {
                if (fs_extra_1.default.existsSync(params[0]))
                    fs_extra_1.default.unlinkSync(params[0]);
                fs_extra_1.default.closeSync(fs_extra_1.default.openSync(params[0], "w"));
            }
            else {
                if (fs_extra_1.default.pathExistsSync(params[0]))
                    fs_extra_1.default.rmdirSync(params[0]);
                fs_extra_1.default.mkdirsSync(params[0]);
            }
        }
    },
    {
        id: 2,
        name: "Copy",
        description: "Copy files or folders",
        params: [
            {
                name: "From Path / Glob",
            },
            {
                name: "To Path / Folder",
            }
        ],
        acceptChilds: false,
        execute: (params) => {
            if (!params[0] || !params[1])
                return;
            //if( isFile(params[1]) && !fs.existsSync(params[1])) fs.mkdirSync(params[1]);
            var items = glob_1.default.sync(params[0]);
            var copyPath = params[1];
            var fileToFolder = false;
            if (!isFile(copyPath)) {
                if (!fs_extra_1.default.existsSync(copyPath))
                    fs_extra_1.default.mkdirSync(copyPath);
                fileToFolder = true;
            }
            items.forEach(SingleItem => {
                if (fileToFolder) {
                    var lastName = path_1.default.basename(SingleItem);
                    if (isFile(lastName))
                        fs_extra_1.default.copyFileSync(SingleItem, path_1.default.join(copyPath, lastName));
                    else
                        fs_extra_1.default.copySync(SingleItem, copyPath);
                }
                else
                    fs_extra_1.default.copySync(SingleItem, copyPath);
            });
        }
    },
    {
        id: 3,
        name: "Has",
        description: "Check file or folder exists in workshop",
        params: [
            {
                name: "File / Glob"
            }
        ],
        acceptChilds: true,
        execute: (params) => {
            if (isFile(params[0])) {
                var files = glob_1.default.sync(params[0]);
                return (files.length > 0);
            }
            else {
                return fs_extra_1.default.pathExistsSync(path_1.default.join(params[0]));
            }
        }
    },
];
exports.default = schemes;
