"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.writeParams = exports.isRelative = exports.getAllDepIDS = exports.getFolders = void 0;
const fs_1 = __importDefault(require("fs"));
const filehound_1 = __importDefault(require("filehound"));
const path_1 = __importDefault(require("path"));
const getFolders = (appPath) => {
    const filehound = filehound_1.default.create();
    filehound
        .path(appPath)
        .directory()
        .depth(3);
    var folders = filehound.findSync();
    var res = [];
    folders.forEach(folder => {
        let fileInfo = {};
        fileInfo.path = folder;
        try {
            fs_1.default.accessSync(folder, fs_1.default.constants.W_OK | fs_1.default.constants.R_OK);
            fileInfo.canAccess = true;
        }
        catch (error) {
            fileInfo.canAccess = false;
        }
        res.push(fileInfo);
    });
    return res;
};
exports.getFolders = getFolders;
const getAllDepIDS = (MyClient, baseIDS) => __awaiter(void 0, void 0, void 0, function* () {
    let lookIDS = baseIDS;
    let willDownloadedIDS = [];
    let fetchedItems = [];
    do {
        willDownloadedIDS = willDownloadedIDS.concat(lookIDS);
        var items = yield MyClient.getItems(lookIDS);
        if (items.success == false)
            return;
        fetchedItems = fetchedItems.concat(items.data);
        var HasChilds = items.data.filter(x => x.children != null && x.children.length > 0);
        if (HasChilds.length > 0) {
            lookIDS = [];
            HasChilds.forEach(SingleItem => {
                var NewIDS = lookIDS.concat(SingleItem.children.map(x => x.publishedfileid));
                NewIDS.forEach(SingleID => {
                    if (willDownloadedIDS.includes(SingleID) === false && lookIDS.includes(SingleID) === false) {
                        lookIDS.push(SingleID);
                    }
                });
            });
        }
        else {
            lookIDS = null;
        }
    } while (lookIDS != null);
    return {
        IDS: willDownloadedIDS,
        Items: fetchedItems
    };
});
exports.getAllDepIDS = getAllDepIDS;
const isRelative = (basePath, targetPath) => {
    var relative = path_1.default.relative(basePath, targetPath);
    return (relative && !relative.startsWith('..') && !path_1.default.isAbsolute(relative));
};
exports.isRelative = isRelative;
const writeParams = (text, params) => {
    const keys = Object.keys(params);
    const isHaveKey = (key) => {
        return keys.includes(key) && params[key] != null && params[key] != undefined;
    };
    const regex = /{(.*?)}/g;
    const result = [...text.matchAll(regex)];
    if (result && result.length > 0) {
        result.forEach(findedRegex => {
            var fullParam = findedRegex[0];
            var innerParam = findedRegex[1];
            var paramValue = null;
            if (innerParam.includes('||')) {
                var split = innerParam.split('||');
                for (var key in split) {
                    var multikey = split[key].replace(" ", "");
                    if (isHaveKey(multikey)) {
                        paramValue = params[multikey];
                        break;
                    }
                }
            }
            else {
                var innerkey = innerParam.replace(" ", "");
                if (isHaveKey(innerkey)) {
                    paramValue = params[innerkey];
                }
            }
            if (paramValue != null) {
                text = text.replace(fullParam, paramValue);
            }
        });
    }
    return text;
};
exports.writeParams = writeParams;
