"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.WebSocket = void 0;
const socket_io_1 = require("socket.io");
const index_1 = require("./index");
const nodejs_file_downloader_1 = __importDefault(require("nodejs-file-downloader"));
const utils_1 = require("../api/utils");
const path_1 = __importDefault(require("path"));
const fs_1 = require("fs");
const wsFolderPreivew_1 = require("./wsFolderPreivew");
const adm_zip_1 = __importDefault(require("adm-zip"));
const config_1 = __importDefault(require("./config"));
const schemeRenderer_1 = require("./schemeRenderer");
class WebSocket {
    constructor(srv) {
        this.sessions = [];
        this.server = new socket_io_1.Server(srv, {
            cors: {
                origin: "*"
            }
        });
        this.server.on("connection", (socket) => this.connection(socket));
    }
    getSession(ID) {
        return this.sessions.find(x => x.socket.id == ID);
    }
    connection(client) {
        console.log("Connected: " + client.id);
        this.sessions.push({
            socket: client,
            items: [],
            previewFolder: new wsFolderPreivew_1.wsFolderPreview(client)
        });
        client.on("download", (args) => {
            this.download(this.getSession(client.id), args.scheme, args.items);
        });
        client.on("disconnect", () => {
            var index = this.sessions.findIndex(x => x.socket.id == client.id);
            if (index != -1)
                this.sessions.splice(index, 1);
        });
    }
    error(session, error) {
        session.socket.emit("error", {
            title: error.title,
            description: error.description
        });
    }
    download(session, scheme, Items) {
        return __awaiter(this, void 0, void 0, function* () {
            var files = yield index_1.wdClient.getFiles(Items.map(x => x.publishedfileid), (statu) => {
                session.socket.emit("statu", {
                    publishedfileid: statu.publishedfileid,
                    progress: statu.progress,
                    progressText: statu.progressText
                });
            });
            if (files.success == false) {
                this.error(session, {
                    title: "Error",
                    description: files.message
                });
                return;
            }
            let getItemName = (ID) => {
                var _a;
                return (_a = Items.find(x => x.publishedfileid == ID)) === null || _a === void 0 ? void 0 : _a.title_disk_safe;
            };
            let downs = [];
            (files.data).forEach(x => {
                var itemName = getItemName(x.publishedfileid);
                var down = new nodejs_file_downloader_1.default({
                    url: (0, utils_1.makeDownloadUrl)(x),
                    directory: "./",
                    onProgress: function (percentage, chunk, remainingSize) {
                        session.socket.emit("statu", {
                            publishedfileid: x.publishedfileid,
                            progress: percentage,
                            progressText: "Downloading %" + percentage
                        });
                    },
                    onBeforeSave: () => {
                        return itemName + ".zip";
                    }
                });
                downs.push(down.download().then(() => {
                    var workshopFolderPath = path_1.default.join(config_1.default.baseConfig.currentPath, itemName);
                    var workshopZipPath = workshopFolderPath + ".zip";
                    var zip = new adm_zip_1.default(workshopZipPath);
                    zip.extractAllTo(workshopFolderPath);
                    (0, fs_1.rmSync)(workshopZipPath, { recursive: true, force: true });
                    if (scheme && config_1.default.savedSchemesConfig.find(x => x.name == scheme) != null) {
                        (0, schemeRenderer_1.execute)(workshopFolderPath, config_1.default.savedSchemesConfig.find(x => x.name == scheme).items, Items.find(x => x.publishedfileid == x.publishedfileid));
                    }
                }));
            });
            yield Promise.all(downs);
            session.socket.emit("prepared", files.data);
        });
    }
}
exports.WebSocket = WebSocket;
