"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.wsFolderPreview = void 0;
const fs_1 = __importDefault(require("fs"));
const fs_extra_1 = __importDefault(require("fs-extra"));
const path_1 = __importDefault(require("path"));
const os_1 = __importDefault(require("os"));
const config_1 = __importDefault(require("./config"));
const schemeRenderer_1 = require("./schemeRenderer");
var folderTypes = [
    {
        name: "Arma Workshop",
        items: [
            {
                name: "meta.cpp"
            },
            {
                name: "mod.cpp"
            },
            {
                name: "addons",
                children: [
                    {
                        name: "myMod.pbo",
                    },
                    {
                        name: "myMod.pbo.MyMod.bisign"
                    }
                ]
            },
            {
                name: "keys",
                children: [
                    {
                        name: "MyMod.bikey",
                    }
                ]
            }
        ]
    },
    {
        name: "City Skylines",
        items: [
            {
                name: "myMod.crp"
            },
            {
                name: "myMod2.crp"
            },
            {
                name: "myMod.xml"
            }
        ]
    }
];
class wsFolderPreview {
    constructor(client) {
        this.SelectedFolder = 0;
        this.Client = client;
        this.Client.on("folderPreview:getExampleFolders", () => {
            this.Client.emit("folderPreview:exampleFolders", folderTypes.map(x => x.name));
        });
        this.Client.on("folderPreview:getSavedSchemes", () => {
            this.Client.emit("folderPreview:savedSchemes", config_1.default.savedSchemesConfig);
        });
        this.Client.on("folderPreview:changeFolder", (name) => {
            this.changeFolder(name);
        });
        this.Client.on("folderPreview:createFolder", () => {
            this.createFolder();
        });
        this.Client.on("folderPreview:readFolder", () => {
            this.readFolder();
        });
        this.Client.on("folderPreview:runSchemes", (schemes) => {
            this.runSchemes(schemes);
        });
        this.Client.on("folderPreview:saveScheme", (data) => {
            this.saveSchemes(data);
        });
        this.Client.on("folderPreview:deleteScheme", (name) => {
            this.deleteScheme(name);
        });
        this.Client.on("disconnect", () => {
            if (this.MainFolderPath && fs_1.default.existsSync(this.MainFolderPath))
                fs_1.default.rmSync(this.MainFolderPath, { recursive: true });
        });
    }
    getChilds(folderpath) {
        var items = fs_1.default.readdirSync(folderpath, { withFileTypes: true });
        var res = [];
        items.forEach(singleItem => {
            var createNew = {
                name: singleItem.name,
                children: null
            };
            if (singleItem.isDirectory())
                createNew.children = this.getChilds(path_1.default.join(folderpath, singleItem.name));
            res.push(createNew);
        });
        return res;
    }
    changeFolder(name) {
        var find = folderTypes.findIndex(x => x.name == name);
        if (find != -1) {
            this.SelectedFolder = find;
            if (this.MainFolderPath && fs_1.default.existsSync(this.MainFolderPath)) {
                fs_1.default.rmSync(this.MainFolderPath, { recursive: true });
            }
            this.createFolder();
        }
    }
    createFolder() {
        if (this.MainFolderPath && fs_1.default.existsSync(this.MainFolderPath))
            fs_1.default.rmSync(this.MainFolderPath, { recursive: true });
        this.MainFolderPath = fs_1.default.mkdtempSync(path_1.default.join(os_1.default.tmpdir(), 'steamwd-fp-'));
        this.SimFolderPath = path_1.default.join(this.MainFolderPath, "sim");
        this.OrjFolderPath = path_1.default.join(this.MainFolderPath, "orj");
        fs_1.default.mkdirSync(this.SimFolderPath);
        fs_1.default.mkdirSync(this.OrjFolderPath);
        var createItem = (Item, currentPath) => {
            if (Item.children == null || Item.children == undefined) {
                fs_1.default.closeSync(fs_1.default.openSync(path_1.default.join(currentPath, Item.name), "w"));
            }
            else {
                currentPath = path_1.default.join(currentPath, Item.name);
                fs_1.default.mkdirSync(currentPath);
                (Item.children).forEach(SingleChild => {
                    createItem(SingleChild, currentPath);
                });
            }
        };
        var myscheme = folderTypes[this.SelectedFolder];
        (myscheme.items).forEach(singleItem => {
            createItem(singleItem, this.OrjFolderPath);
        });
        this.copyOrjToSim();
        this.readFolder();
    }
    copyOrjToSim() {
        if (fs_1.default.existsSync(this.SimFolderPath)) {
            fs_1.default.rmSync(this.SimFolderPath, { recursive: true });
        }
        fs_extra_1.default.copySync(this.OrjFolderPath, this.SimFolderPath, { overwrite: true });
    }
    readFolder() {
        if (this.SimFolderPath && fs_1.default.existsSync(this.SimFolderPath))
            this.Client.emit("folderPreview:mainFolder", this.MainFolderPath);
        this.Client.emit("folderPreview:folder", this.getChilds(this.SimFolderPath));
    }
    runSchemes(schemes) {
        this.copyOrjToSim();
        if (schemes == null || schemes.length <= 0) {
            this.readFolder();
            return;
        }
        const params = {
            safe_disk_title: folderTypes[this.SelectedFolder].name.toLocaleLowerCase().replace(" ", "")
        };
        try {
            (0, schemeRenderer_1.execute)(this.SimFolderPath, schemes, params);
        }
        catch (error) {
            this.sendError(error.message || error);
        }
        this.readFolder();
    }
    saveSchemes(data) {
        if (!data.name)
            return;
        if (!data.items)
            return;
        let find = config_1.default.savedSchemesConfig.find(x => x.name == data.name);
        if (find)
            find.items = data.items;
        else
            config_1.default.savedSchemesConfig.push(data);
        config_1.default.updateSavedSchemes(config_1.default.savedSchemesConfig);
        this.Client.emit("folderPreview:savedSchemes", config_1.default.savedSchemesConfig);
    }
    deleteScheme(name) {
        if (!name)
            return;
        config_1.default.savedSchemesConfig = config_1.default.savedSchemesConfig.filter(x => x.name != name);
        config_1.default.updateSavedSchemes(config_1.default.savedSchemesConfig);
        this.Client.emit("folderPreview:savedSchemes", config_1.default.savedSchemesConfig);
    }
    sendError(msg) {
        this.Client.emit("folderPreview:error", msg);
    }
}
exports.wsFolderPreview = wsFolderPreview;
